Rename (create|free)_url_spec() to _pattern_spec()
authorFabian Keil <fk@fabiankeil.de>
Sun, 24 Nov 2013 14:25:19 +0000 (14:25 +0000)
committerFabian Keil <fk@fabiankeil.de>
Sun, 24 Nov 2013 14:25:19 +0000 (14:25 +0000)
They deal with all kinds of patterns now.

actions.c
cgiedit.c
loadcfg.c
loaders.c
urlmatch.c
urlmatch.h

index b07d8bc..81a2f7a 100644 (file)
--- a/actions.c
+++ b/actions.c
@@ -1,4 +1,4 @@
-const char actions_rcs[] = "$Id: actions.c,v 1.88 2013/11/24 14:22:51 fabiankeil Exp $";
+const char actions_rcs[] = "$Id: actions.c,v 1.89 2013/11/24 14:24:17 fabiankeil Exp $";
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/actions.c,v $
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/actions.c,v $
@@ -991,7 +991,7 @@ void unload_actions_file(void *file_data)
    while (cur != NULL)
    {
       next = cur->next;
    while (cur != NULL)
    {
       next = cur->next;
-      free_url_spec(cur->url);
+      free_pattern_spec(cur->url);
       if ((next == NULL) || (next->action != cur->action))
       {
          /*
       if ((next == NULL) || (next->action != cur->action))
       {
          /*
@@ -1571,7 +1571,7 @@ static int load_one_actions_file(struct client_state *csp, int fileid)
          cur_action_used = 1;
 
          /* Save the URL pattern */
          cur_action_used = 1;
 
          /* Save the URL pattern */
-         if (create_url_spec(perm->url, buf))
+         if (create_pattern_spec(perm->url, buf))
          {
             fclose(fp);
             log_error(LOG_LEVEL_FATAL,
          {
             fclose(fp);
             log_error(LOG_LEVEL_FATAL,
index f52f503..cb824f9 100644 (file)
--- a/cgiedit.c
+++ b/cgiedit.c
@@ -1,4 +1,4 @@
-const char cgiedit_rcs[] = "$Id: cgiedit.c,v 1.77 2013/11/06 16:28:00 fabiankeil Exp $";
+const char cgiedit_rcs[] = "$Id: cgiedit.c,v 1.78 2013/11/24 14:22:51 fabiankeil Exp $";
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/cgiedit.c,v $
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/cgiedit.c,v $
@@ -1875,14 +1875,14 @@ static jb_err get_url_spec_param(struct client_state *csp,
       free(param);
       return JB_ERR_MEMORY;
    }
       free(param);
       return JB_ERR_MEMORY;
    }
-   err = create_url_spec(compiled, s);
+   err = create_pattern_spec(compiled, s);
    free(s);
    if (err)
    {
       free(param);
       return (err == JB_ERR_MEMORY) ? JB_ERR_MEMORY : JB_ERR_CGI_PARAMS;
    }
    free(s);
    if (err)
    {
       free(param);
       return (err == JB_ERR_MEMORY) ? JB_ERR_MEMORY : JB_ERR_CGI_PARAMS;
    }
-   free_url_spec(compiled);
+   free_pattern_spec(compiled);
 
    if (param[strlen(param) - 1] == '\\')
    {
 
    if (param[strlen(param) - 1] == '\\')
    {
@@ -1911,14 +1911,14 @@ static jb_err get_url_spec_param(struct client_state *csp,
          free(param);
          return JB_ERR_MEMORY;
       }
          free(param);
          return JB_ERR_MEMORY;
       }
-      err = create_url_spec(compiled, s);
+      err = create_pattern_spec(compiled, s);
       free(s);
       if (err)
       {
          free(param);
          return (err == JB_ERR_MEMORY) ? JB_ERR_MEMORY : JB_ERR_CGI_PARAMS;
       }
       free(s);
       if (err)
       {
          free(param);
          return (err == JB_ERR_MEMORY) ? JB_ERR_MEMORY : JB_ERR_CGI_PARAMS;
       }
-      free_url_spec(compiled);
+      free_pattern_spec(compiled);
    }
 
    *pvalue = param;
    }
 
    *pvalue = param;
index fc31e2c..5b175a6 100644 (file)
--- a/loadcfg.c
+++ b/loadcfg.c
@@ -1,4 +1,4 @@
-const char loadcfg_rcs[] = "$Id: loadcfg.c,v 1.137 2013/03/07 14:08:49 fabiankeil Exp $";
+const char loadcfg_rcs[] = "$Id: loadcfg.c,v 1.138 2013/04/23 09:42:53 fabiankeil Exp $";
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/loadcfg.c,v $
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/loadcfg.c,v $
@@ -209,7 +209,7 @@ static void unload_configfile (void * data)
    while (cur_fwd != NULL)
    {
       struct forward_spec * next_fwd = cur_fwd->next;
    while (cur_fwd != NULL)
    {
       struct forward_spec * next_fwd = cur_fwd->next;
-      free_url_spec(cur_fwd->url);
+      free_pattern_spec(cur_fwd->url);
 
       freez(cur_fwd->gateway_host);
       freez(cur_fwd->forward_host);
 
       freez(cur_fwd->gateway_host);
       freez(cur_fwd->forward_host);
@@ -937,7 +937,7 @@ struct configuration_spec * load_config(void)
             cur_fwd->type = SOCKS_NONE;
 
             /* Save the URL pattern */
             cur_fwd->type = SOCKS_NONE;
 
             /* Save the URL pattern */
-            if (create_url_spec(cur_fwd->url, vec[0]))
+            if (create_pattern_spec(cur_fwd->url, vec[0]))
             {
                log_error(LOG_LEVEL_ERROR, "Bad URL specifier for forward "
                      "directive in configuration file.");
             {
                log_error(LOG_LEVEL_ERROR, "Bad URL specifier for forward "
                      "directive in configuration file.");
@@ -992,7 +992,7 @@ struct configuration_spec * load_config(void)
             cur_fwd->type = SOCKS_4;
 
             /* Save the URL pattern */
             cur_fwd->type = SOCKS_4;
 
             /* Save the URL pattern */
-            if (create_url_spec(cur_fwd->url, vec[0]))
+            if (create_pattern_spec(cur_fwd->url, vec[0]))
             {
                log_error(LOG_LEVEL_ERROR, "Bad URL specifier for forward-socks4 "
                      "directive in configuration file.");
             {
                log_error(LOG_LEVEL_ERROR, "Bad URL specifier for forward-socks4 "
                      "directive in configuration file.");
@@ -1072,7 +1072,7 @@ struct configuration_spec * load_config(void)
             }
 
             /* Save the URL pattern */
             }
 
             /* Save the URL pattern */
-            if (create_url_spec(cur_fwd->url, vec[0]))
+            if (create_pattern_spec(cur_fwd->url, vec[0]))
             {
                log_error(LOG_LEVEL_ERROR, "Bad URL specifier for forward-socks4a "
                      "directive in configuration file.");
             {
                log_error(LOG_LEVEL_ERROR, "Bad URL specifier for forward-socks4a "
                      "directive in configuration file.");
index 292ca7f..37b7d65 100644 (file)
--- a/loaders.c
+++ b/loaders.c
@@ -1,4 +1,4 @@
-const char loaders_rcs[] = "$Id: loaders.c,v 1.95 2013/01/13 15:38:14 fabiankeil Exp $";
+const char loaders_rcs[] = "$Id: loaders.c,v 1.96 2013/11/24 14:22:51 fabiankeil Exp $";
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/loaders.c,v $
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/loaders.c,v $
@@ -779,7 +779,7 @@ static void unload_trustfile(void *f)
    {
       next = cur->next;
 
    {
       next = cur->next;
 
-      free_url_spec(cur->url);
+      free_pattern_spec(cur->url);
       free(cur);
 
       cur = next;
       free(cur);
 
       cur = next;
@@ -908,7 +908,7 @@ int load_trustfile(struct client_state *csp)
       b->reject = reject;
 
       /* Save the URL pattern */
       b->reject = reject;
 
       /* Save the URL pattern */
-      if (create_url_spec(b->url, buf))
+      if (create_pattern_spec(b->url, buf))
       {
          fclose(fp);
          goto load_trustfile_error;
       {
          fclose(fp);
          goto load_trustfile_error;
@@ -1014,7 +1014,7 @@ static void unload_re_filterfile(void *f)
  *********************************************************************/
 void unload_forward_spec(struct forward_spec *fwd)
 {
  *********************************************************************/
 void unload_forward_spec(struct forward_spec *fwd)
 {
-   free_url_spec(fwd->url);
+   free_pattern_spec(fwd->url);
    freez(fwd->gateway_host);
    freez(fwd->forward_host);
    free(fwd);
    freez(fwd->gateway_host);
    freez(fwd->forward_host);
    free(fwd);
index 092ae0f..8c8506f 100644 (file)
@@ -1,4 +1,4 @@
-const char urlmatch_rcs[] = "$Id: urlmatch.c,v 1.76 2013/11/24 14:22:51 fabiankeil Exp $";
+const char urlmatch_rcs[] = "$Id: urlmatch.c,v 1.77 2013/11/24 14:24:18 fabiankeil Exp $";
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/urlmatch.c,v $
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/urlmatch.c,v $
@@ -610,7 +610,7 @@ static jb_err compile_pattern(const char *pattern, enum regex_anchoring anchorin
    *regex = zalloc(sizeof(**regex));
    if (NULL == *regex)
    {
    *regex = zalloc(sizeof(**regex));
    if (NULL == *regex)
    {
-      free_url_spec(url);
+      free_pattern_spec(url);
       return JB_ERR_MEMORY;
    }
 
       return JB_ERR_MEMORY;
    }
 
@@ -628,7 +628,7 @@ static jb_err compile_pattern(const char *pattern, enum regex_anchoring anchorin
       rebuf[errlen] = '\0';
       log_error(LOG_LEVEL_ERROR, "error compiling %s from %s: %s",
          pattern, url->spec, rebuf);
       rebuf[errlen] = '\0';
       log_error(LOG_LEVEL_ERROR, "error compiling %s from %s: %s",
          pattern, url->spec, rebuf);
-      free_url_spec(url);
+      free_pattern_spec(url);
 
       return JB_ERR_PARSE;
    }
 
       return JB_ERR_PARSE;
    }
@@ -801,7 +801,7 @@ static jb_err compile_host_pattern(struct pattern_spec *url, const char *host_pa
 
    if (url->dcount < 0)
    {
 
    if (url->dcount < 0)
    {
-      free_url_spec(url);
+      free_pattern_spec(url);
       return JB_ERR_PARSE;
    }
    else if (url->dcount != 0)
       return JB_ERR_PARSE;
    }
    else if (url->dcount != 0)
@@ -1084,18 +1084,18 @@ static int domain_match(const struct pattern_spec *pattern, const struct http_re
 
 /*********************************************************************
  *
 
 /*********************************************************************
  *
- * Function    :  create_url_spec
+ * Function    :  create_pattern_spec
  *
  *
* Description :  Creates a "url_spec" structure from a string.
*                When finished, free with free_url_spec().
  *
  * Parameters  :
  *
  * Parameters  :
- *          1  :  url = Target url_spec to be filled in.  Will be
- *                      zeroed before use.
+ *          1  :  pattern = Target pattern_spec to be filled in.
+ *                          Will be zeroed before use.
  *          2  :  buf = Source pattern, null terminated.  NOTE: The
  *                      contents of this buffer are destroyed by this
  *                      function.  If this function succeeds, the
  *          2  :  buf = Source pattern, null terminated.  NOTE: The
  *                      contents of this buffer are destroyed by this
  *                      function.  If this function succeeds, the
- *                      buffer is copied to url->spec.  If this
+ *                      buffer is copied to pattern->spec.  If this
  *                      function fails, the contents of the buffer
  *                      are lost forever.
  *
  *                      function fails, the contents of the buffer
  *                      are lost forever.
  *
@@ -1104,86 +1104,86 @@ static int domain_match(const struct pattern_spec *pattern, const struct http_re
  *                               written to system log)
  *
  *********************************************************************/
  *                               written to system log)
  *
  *********************************************************************/
-jb_err create_url_spec(struct pattern_spec *url, char *buf)
+jb_err create_pattern_spec(struct pattern_spec *pattern, char *buf)
 {
 {
-   assert(url);
+   assert(pattern);
    assert(buf);
 
    assert(buf);
 
-   memset(url, '\0', sizeof(*url));
+   memset(pattern, '\0', sizeof(*pattern));
 
    /* Remember the original specification for the CGI pages. */
 
    /* Remember the original specification for the CGI pages. */
-   url->spec = strdup_or_die(buf);
+   pattern->spec = strdup_or_die(buf);
 
    /* Is it a positive tag pattern? */
 
    /* Is it a positive tag pattern? */
-   if (0 == strncmpic(url->spec, "TAG:", 4))
+   if (0 == strncmpic(pattern->spec, "TAG:", 4))
    {
       /* The pattern starts with the first character after "TAG:" */
       const char *tag_pattern = buf + 4;
    {
       /* The pattern starts with the first character after "TAG:" */
       const char *tag_pattern = buf + 4;
-      url->flags |= PATTERN_SPEC_TAG_PATTERN;
-      return compile_pattern(tag_pattern, NO_ANCHORING, url, &url->pattern.tag_regex);
+      pattern->flags |= PATTERN_SPEC_TAG_PATTERN;
+      return compile_pattern(tag_pattern, NO_ANCHORING, pattern, &pattern->pattern.tag_regex);
    }
    /* Is it a negative tag pattern? */
    }
    /* Is it a negative tag pattern? */
-   if (0 == strncmpic(url->spec, "NO-REQUEST-TAG:", 15))
+   if (0 == strncmpic(pattern->spec, "NO-REQUEST-TAG:", 15))
    {
       /* The pattern starts with the first character after "NO-REQUEST-TAG:" */
       const char *tag_pattern = buf + 15;
    {
       /* The pattern starts with the first character after "NO-REQUEST-TAG:" */
       const char *tag_pattern = buf + 15;
-      url->flags |= PATTERN_SPEC_NO_REQUEST_TAG_PATTERN;
-      return compile_pattern(tag_pattern, NO_ANCHORING, url, &url->pattern.tag_regex);
+      pattern->flags |= PATTERN_SPEC_NO_REQUEST_TAG_PATTERN;
+      return compile_pattern(tag_pattern, NO_ANCHORING, pattern, &pattern->pattern.tag_regex);
    }
    }
-   if (0 == strncmpic(url->spec, "NO-RESPONSE-TAG:", 16))
+   if (0 == strncmpic(pattern->spec, "NO-RESPONSE-TAG:", 16))
    {
       /* The pattern starts with the first character after "NO-RESPONSE-TAG:" */
       const char *tag_pattern = buf + 16;
    {
       /* The pattern starts with the first character after "NO-RESPONSE-TAG:" */
       const char *tag_pattern = buf + 16;
-      url->flags |= PATTERN_SPEC_NO_RESPONSE_TAG_PATTERN;
-      return compile_pattern(tag_pattern, NO_ANCHORING, url, &url->pattern.tag_regex);
+      pattern->flags |= PATTERN_SPEC_NO_RESPONSE_TAG_PATTERN;
+      return compile_pattern(tag_pattern, NO_ANCHORING, pattern, &pattern->pattern.tag_regex);
    }
 
    }
 
-   url->flags |= PATTERN_SPEC_URL_PATTERN;
+   pattern->flags |= PATTERN_SPEC_URL_PATTERN;
 
    /* If it isn't a tag pattern it must be an URL pattern. */
 
    /* If it isn't a tag pattern it must be an URL pattern. */
-   return compile_url_pattern(url, buf);
+   return compile_url_pattern(pattern, buf);
 }
 
 
 /*********************************************************************
  *
 }
 
 
 /*********************************************************************
  *
- * Function    :  free_url_spec
+ * Function    :  free_pattern_spec
  *
  *
- * Description :  Called from the "unloaders".  Freez the url
+ * Description :  Called from the "unloaders".  Freez the pattern
  *                structure elements.
  *
  * Parameters  :
  *                structure elements.
  *
  * Parameters  :
- *          1  :  url = pointer to a pattern_spec structure.
+ *          1  :  pattern = pointer to a pattern_spec structure.
  *
  * Returns     :  N/A
  *
  *********************************************************************/
  *
  * Returns     :  N/A
  *
  *********************************************************************/
-void free_url_spec(struct pattern_spec *url)
+void free_pattern_spec(struct pattern_spec *pattern)
 {
 {
-   if (url == NULL) return;
+   if (pattern == NULL) return;
 
 
-   freez(url->spec);
+   freez(pattern->spec);
 #ifdef FEATURE_EXTENDED_HOST_PATTERNS
 #ifdef FEATURE_EXTENDED_HOST_PATTERNS
-   if (url->pattern.url_spec.host_regex)
+   if (pattern->pattern.url_spec.host_regex)
    {
    {
-      regfree(url->pattern.url_spec.host_regex);
-      freez(url->pattern.url_spec.host_regex);
+      regfree(pattern->pattern.url_spec.host_regex);
+      freez(pattern->pattern.url_spec.host_regex);
    }
 #else
    }
 #else
-   freez(url->pattern.url_spec.dbuffer);
-   freez(url->pattern.url_spec.dvec);
-   url->pattern.url_spec.dcount = 0;
+   freez(pattern->pattern.url_spec.dbuffer);
+   freez(pattern->pattern.url_spec.dvec);
+   pattern->pattern.url_spec.dcount = 0;
 #endif /* ndef FEATURE_EXTENDED_HOST_PATTERNS */
 #endif /* ndef FEATURE_EXTENDED_HOST_PATTERNS */
-   freez(url->pattern.url_spec.port_list);
-   if (url->pattern.url_spec.preg)
+   freez(pattern->pattern.url_spec.port_list);
+   if (pattern->pattern.url_spec.preg)
    {
    {
-      regfree(url->pattern.url_spec.preg);
-      freez(url->pattern.url_spec.preg);
+      regfree(pattern->pattern.url_spec.preg);
+      freez(pattern->pattern.url_spec.preg);
    }
    }
-   if (url->pattern.tag_regex)
+   if (pattern->pattern.tag_regex)
    {
    {
-      regfree(url->pattern.tag_regex);
-      freez(url->pattern.tag_regex);
+      regfree(pattern->pattern.tag_regex);
+      freez(pattern->pattern.tag_regex);
    }
 }
 
    }
 }
 
index 67f59d0..35befbd 100644 (file)
@@ -1,6 +1,6 @@
 #ifndef URLMATCH_H_INCLUDED
 #define URLMATCH_H_INCLUDED
 #ifndef URLMATCH_H_INCLUDED
 #define URLMATCH_H_INCLUDED
-#define URLMATCH_H_VERSION "$Id: urlmatch.h,v 1.19 2013/11/24 14:22:51 fabiankeil Exp $"
+#define URLMATCH_H_VERSION "$Id: urlmatch.h,v 1.20 2013/11/24 14:23:28 fabiankeil Exp $"
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/urlmatch.h,v $
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/urlmatch.h,v $
@@ -53,8 +53,8 @@ extern int url_requires_percent_encoding(const char *url);
 extern int url_match(const struct pattern_spec *pattern,
                      const struct http_request *http);
 
 extern int url_match(const struct pattern_spec *pattern,
                      const struct http_request *http);
 
-extern jb_err create_url_spec(struct pattern_spec *url, char *buf);
-extern void free_url_spec(struct pattern_spec *url);
+extern jb_err create_pattern_spec(struct pattern_spec *url, char *buf);
+extern void free_pattern_spec(struct pattern_spec *url);
 extern int match_portlist(const char *portlist, int port);
 extern jb_err parse_forwarder_address(char *address, char **hostname, int *port);
 
@@ -1084,18 +1084,18 @@ static int domain_match(const struct pattern_spec *pattern, const struct http_re
  *
  *
- * Description :  Creates a "url_spec" structure from a string.
- *                When finished, free with free_url_spec().
+ * Description :  Creates a "pattern_spec" structure from a string.
+ *                When finished, free with free_pattern_spec().
  *
  * Parameters  :
 extern int match_portlist(const char *portlist, int port);
 extern jb_err parse_forwarder_address(char *address, char **hostname, int *port);